==> lambdastepfunctions-1.115.0-sources.jar: software/amazon/awsconstructs/services/lambdastepfunctions/LambdaToStepfunctions.java <==
package software.amazon.awsconstructs.services.lambdastepfunctions;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.32.0 (build 3f4fe23)", date = "2021-08-11T23:45:36.104Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdastepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctions")
public class LambdaToStepfunctions extends software.amazon.awscdk.core.Construct {

    protected LambdaToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToStepfunctions(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctionsProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctionsProps.Builder();
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineEnvironmentVariableName Optional Name for the Step Functions state machine environment variable set for the producer Lambda function. This parameter is required.
         */
        public Builder stateMachineEnvironmentVariableName(final java.lang.String stateMachineEnvironmentVariableName) {
            this.props.stateMachineEnvironmentVariableName(stateMachineEnvironmentVariableName);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions build() {
            return new software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdastepfunctions-1.119.0-sources.jar: software/amazon/awsconstructs/services/lambdastepfunctions/LambdaToStepfunctions.java <==
package software.amazon.awsconstructs.services.lambdastepfunctions;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-02T18:45:35.347Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdastepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctions")
public class LambdaToStepfunctions extends software.amazon.awscdk.core.Construct {

    protected LambdaToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToStepfunctions(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctionsProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctionsProps.Builder();
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineEnvironmentVariableName Optional Name for the Step Functions state machine environment variable set for the producer Lambda function. This parameter is required.
         */
        public Builder stateMachineEnvironmentVariableName(final java.lang.String stateMachineEnvironmentVariableName) {
            this.props.stateMachineEnvironmentVariableName(stateMachineEnvironmentVariableName);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions build() {
            return new software.amazon.awsconstructs.services.lambdastepfunctions.LambdaToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
